<?php
/**
 * OneType Theme Customizer
 */

// Loads custom control
require trailingslashit( get_template_directory() ) . 'inc/customizer/controls/custom-text.php';

// Loads the customizer settings
require trailingslashit( get_template_directory() ) . 'inc/customizer/general.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/post.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/page.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/shop.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/blog.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/footer.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/fonts.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/colors.php';

/**
 * Custom customizer functions.
 */
function onetype_customize_functions( $wp_customize ) {

	// Register new panel: Design
	$wp_customize->add_panel( 'onetype_design', array(
		'title'       => esc_html__( 'Design', 'onetype' ),
		'description' => esc_html__( 'This panel is used for customizing the design of your site.', 'onetype' ),
		'priority'    => 125,
	) );

	// Register new panel: Theme Options
	$wp_customize->add_panel( 'onetype_options', array(
		'title'       => esc_html__( 'Theme Options', 'onetype' ),
		'description' => esc_html__( 'This panel is used for customizing the OneType theme.', 'onetype' ),
		'priority'    => 130,
	) );

	// Live preview of Site Title
	$wp_customize->get_setting( 'blogname' )->transport = 'postMessage';

	// Enable selective refresh to the Site Title
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'            => '.site-title a',
			'settings'         => array( 'blogname' ),
			'render_callback'  => function() {
				return get_bloginfo( 'name', 'display' );
			}
		) );
	}

	// Move the Colors section.
	$wp_customize->get_section( 'colors' )->panel    = 'onetype_design';
	$wp_customize->get_section( 'colors' )->priority = 1;

	// Move the Theme Layout
	$wp_customize->get_section( 'layout' )->panel    = 'onetype_design';
	$wp_customize->get_section( 'layout' )->title    = esc_html__( 'Layouts', 'onetype' );
	$wp_customize->get_section( 'layout' )->priority = 5;
	$wp_customize->get_control( 'theme-layout-control' )->label    = esc_html__( 'Post / Page Layout', 'onetype' );
	$wp_customize->get_control( 'theme-layout-control' )->priority = 1;
	$wp_customize->get_control( 'theme-layout-control' )->active_callback = function() {
		return !is_front_page() && is_page() || is_single() ;
	};

	// Move the Background Image section.
	$wp_customize->get_section( 'background_image' )->panel    = 'onetype_design';
	$wp_customize->get_section( 'background_image' )->priority = 7;

	// Move the Static Front Page section.
	$wp_customize->get_section( 'static_front_page' )->panel    = 'onetype_design';
	$wp_customize->get_section( 'static_front_page' )->priority = 9;

	// Move the Additional CSS section.
	$wp_customize->get_section( 'custom_css' )->panel    = 'onetype_design';
	$wp_customize->get_section( 'custom_css' )->priority = 11;

	// Move background color to background image section.
	$wp_customize->get_section( 'background_image' )->title = esc_html__( 'Background', 'onetype' );
	$wp_customize->get_control( 'background_color' )->section = 'background_image';


}
add_action( 'customize_register', 'onetype_customize_functions', 99 );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function onetype_customize_preview_js() {
	wp_enqueue_script( 'onetype-customizer', get_template_directory_uri() . '/assets/js/customizer/customizer.js', array( 'customize-preview', 'jquery' ) );
}
add_action( 'customize_preview_init', 'onetype_customize_preview_js' );

/**
 * Display theme documentation on customizer page.
 */
function onetype_documentation_link() {

	// Enqueue the script
	wp_enqueue_script( 'onetype-doc', get_template_directory_uri() . '/assets/js/customizer/doc.js', array(), '1.0.0', true );

	// Localize the script
	wp_localize_script( 'onetype-doc', 'prefixL10n',
		array(
			'prefixURL'   => esc_url( 'http://docs.theme-junkie.com/onetype/' ),
			'prefixLabel' => esc_html__( 'Documentation', 'onetype' ),
		)
	);

}
add_action( 'customize_controls_enqueue_scripts', 'onetype_documentation_link' );

/**
 * Custom styles.
 */
function onetype_custom_css() {

	// Set up empty variable.
	$css = '';

	// Get the customizer value.
	$color                = get_theme_mod( 'onetype_accent_color', '#d87f3b' );
	$footer_bg_color      = get_theme_mod( 'onetype_footer_bg', '#e7e7e7' );
	$site_title_color     = get_theme_mod( 'onetype_site_title_color', '#231f20' );
	$header_bg_color      = get_theme_mod( 'onetype_header_bg_color', '#ffffff' );
	$navigation_color     = get_theme_mod( 'onetype_navigation_color', '#231f20' );
	$page_header_bg_color = get_theme_mod( 'onetype_page_header_bg_color', '#f9f9f9' );
	$post_title_color     = get_theme_mod( 'onetype_post_title_color', '#ffffff' );
	$heading_font         = get_theme_mod( 'onetype_heading_font_family', '\'Montserrat\', sans-serif' );
	$body_font            = get_theme_mod( 'onetype_body_font_family', '\'Lato\', sans-serif' );

	if ( $color != '#d87f3b' ) {
		$css .= '
		.author-badge, .widget_tag_cloud a {
			background-color: ' . sanitize_hex_color( $color ) . ';
		}

		a:visited, a:visited:hover, a:hover, .menu-primary-items a:hover, .menu-primary-items a:visited:hover, .site-branding h1 a:hover, h2.entry-title a:hover, .page-title a:hover, .post-pagination .post-detail span, .post-meta .cat-link a:hover, .post-meta .tag-links a:hover, .post-meta .post-author .url:hover, .pagination .page-numbers.current, .pagination .page-numbers:hover, .traditional-pagination div a:hover, .author-bio .name a:hover, .comment-avatar .name a:hover, .home .page-header .page-title a:hover, .posts-thumbnail-widget .post-title:hover, .woocommerce-tabs ul.tabs li.active a {
			color: ' . sanitize_hex_color( $color ) . ';
		}

		blockquote {
			border-color: ' . sanitize_hex_color( $color ) . ';
		}
		';
	}

	if ( $heading_font != '\'Montserrat\', sans-serif' ) {
		$css .= '
			h1, h2, h3, h4, h5, h6, .entry-author {
				font-family: ' . esc_attr( $heading_font ) . ';
			}
		';
	}

	if ( $body_font != '\'Lato\', sans-serif' ) {
		$css .= '
			body {
				font-family: ' . esc_attr( $body_font ) . ';
			}
		';
	}

	if ( $site_title_color != '#231f20' ) {
		$css .= '.site-branding h1 a { color: ' . sanitize_hex_color( $site_title_color ) . '; }';
	}

	if ( $header_bg_color != '#ffffff' ) {
		$css .= 'body:not(.page-template-transparent-header) .site-header { background-color: ' . sanitize_hex_color( $header_bg_color ) . '; }';
	}

	if ( $navigation_color != '#231f20' ) {
		$css .= '.menu-primary-items a, .menu-primary-items a:visited { color: ' . sanitize_hex_color( $navigation_color ) . '; }';
	}

	if ( $page_header_bg_color != '#f9f9f9' ) {
		$css .= '.page-header { background-color: ' . sanitize_hex_color( $page_header_bg_color ) . '; }';
	}

	if ( $post_title_color != '#ffffff' ) {
		$css .= '.page-header .page-title, .has-post-thumbnail .page-header .page-title { color: ' . sanitize_hex_color( $post_title_color ) . '; }';
	}

	if ( $footer_bg_color != '#e7e7e7' ) {
		$css .= '.site-footer { background-color: ' . sanitize_hex_color( $footer_bg_color ) . '; }';
	}

	// Print the custom style
	wp_add_inline_style( 'onetype-style', $css );

}
add_action( 'wp_enqueue_scripts', 'onetype_custom_css' );

/**
 * Sanitize the checkbox.
 *
 * @param boolean $input.
 * @return boolean (true|false).
 */
function onetype_sanitize_checkbox( $input ) {
	if ( 1 == $input ) {
		return true;
	} else {
		return false;
	}
}

/**
 * Sanitize the Footer Credits
 */
function onetype_sanitize_textarea( $text ) {
	if ( current_user_can( 'unfiltered_html' ) ) {
		$text = $text;
	} else {
		$text = wp_kses_post( $text );
	}
	return $text;
}

/**
 * Sanitize the container style value.
 */
function onetype_sanitize_container_style( $style ) {
	if ( ! in_array( $style, array( 'fullwidth', 'boxed', 'framed' ) ) ) {
		$style = 'fullwidth';
	}
	return $style;
}

/**
 * Sanitize the pagination type value.
 */
function onetype_sanitize_posts_pagination( $type ) {
	if ( ! in_array( $type, array( 'number', 'traditional' ) ) ) {
		$type = 'number';
	}
	return $type;
}

/**
 * Sanitize the pagination type value.
 */
function onetype_sanitize_post_meta( $show ) {
	if ( ! in_array( $show, array( 'enable', 'disable' ) ) ) {
		$show = 'enable';
	}
	return $show;
}

/**
 * Sanitize shop layouts value.
 */
function onetype_sanitize_blog_layouts( $layout ) {
	if ( ! in_array( $layout,
			array(
				'2c-l',
				'2c-r',
				'1c',
			)
		)
	) {
		$layout = '2c-r';
	}
	return $layout;
}

/**
 * Sanitize blog layouts value.
 */
function onetype_blog_layouts( $layout ) {
	if ( ! in_array( $layout,
			array(
				'2c-l',
				'2c-r',
				'1c',
			)
		)
	) {
		$layout = '2c-r';
	}
	return $layout;
}
