<?php
/**
 * Post Customizer
 */

/**
 * Register the customizer.
 */
function onetype_post_customize_register( $wp_customize ) {

	// Register new section: Post
	$wp_customize->add_section( 'onetype_post' , array(
		'title'       => esc_html__( 'Post', 'onetype' ),
		'description' => '',
		'panel'       => 'onetype_options',
		'priority'    => 5
	) );

	// Register Post info setting
	$wp_customize->add_setting( 'onetype_post_info', array(
		'default'           => '',
		'sanitize_callback' => 'esc_attr'
	) );
	$wp_customize->add_control( new OneType_Custom_Text( $wp_customize, 'onetype_post_info', array(
		'label'             => '',
		'description'       => esc_html__( 'This page is not a post page or single post. Please navigate to post page while using the Customizer to view the options.', 'onetype' ),
		'section'           => 'onetype_post',
		'priority'          => 1,
		'active_callback' => function() {
			return !is_single();
		}
	) ) );

	// Register footer content setting
	$wp_customize->add_setting( 'onetype_post_meta', array(
		'default'           => 'enable',
		'sanitize_callback' => 'onetype_sanitize_post_meta',
	) );
	$wp_customize->add_control( 'onetype_post_meta', array(
		'label'             => esc_html__( 'Post Meta', 'onetype' ),
		'description'       => '',
		'section'           => 'onetype_post',
		'priority'          => 1,
		'type'              => 'radio',
		'choices'           => array(
			'disable' => esc_html__( 'Disable', 'onetype' ),
			'enable'  => esc_html__( 'Enable', 'onetype' )
		),
		'active_callback' => function() {
			return is_single();
		}
	) );

	// Register Avatar setting
	$wp_customize->add_setting( 'onetype_author_avatar', array(
		'default'           => 1,
		'sanitize_callback' => 'onetype_sanitize_checkbox',
	) );
	$wp_customize->add_control( 'onetype_author_avatar', array(
		'label'             => esc_html__( 'Show author avatar', 'onetype' ),
		'section'           => 'onetype_post',
		'priority'          => 3,
		'type'              => 'checkbox',
		'active_callback'   => 'onetype_is_post_meta_enable'
	) );

	// Register Date setting
	$wp_customize->add_setting( 'onetype_post_date', array(
		'default'           => 1,
		'sanitize_callback' => 'onetype_sanitize_checkbox',
	) );
	$wp_customize->add_control( 'onetype_post_date', array(
		'label'             => esc_html__( 'Show post date', 'onetype' ),
		'section'           => 'onetype_post',
		'priority'          => 5,
		'type'              => 'checkbox',
		'active_callback'   => 'onetype_is_post_meta_enable'
	) );

	// Register Category setting
	$wp_customize->add_setting( 'onetype_post_cat', array(
		'default'           => 1,
		'sanitize_callback' => 'onetype_sanitize_checkbox',
	) );
	$wp_customize->add_control( 'onetype_post_cat', array(
		'label'             => esc_html__( 'Show post categories', 'onetype' ),
		'section'           => 'onetype_post',
		'priority'          => 7,
		'type'              => 'checkbox',
		'active_callback'   => 'onetype_is_post_meta_enable'
	) );

	// Register Tag setting
	$wp_customize->add_setting( 'onetype_post_tag', array(
		'default'           => 1,
		'sanitize_callback' => 'onetype_sanitize_checkbox',
	) );
	$wp_customize->add_control( 'onetype_post_tag', array(
		'label'             => esc_html__( 'Show post tags', 'onetype' ),
		'section'           => 'onetype_post',
		'priority'          => 9,
		'type'              => 'checkbox',
		'active_callback'   => 'onetype_is_post_meta_enable'
	) );

	// Register Author Box setting
	$wp_customize->add_setting( 'onetype_author_box', array(
		'default'           => 1,
		'sanitize_callback' => 'onetype_sanitize_checkbox',
	) );
	$wp_customize->add_control( 'onetype_author_box', array(
		'label'             => esc_html__( 'Show author box', 'onetype' ),
		'section'           => 'onetype_post',
		'priority'          => 11,
		'type'              => 'checkbox',
		'active_callback' => function() {
			return is_single();
		}
	) );

	// Register Related Posts setting
	$wp_customize->add_setting( 'onetype_related_posts', array(
		'default'           => 1,
		'sanitize_callback' => 'onetype_sanitize_checkbox',
	) );
	$wp_customize->add_control( 'onetype_related_posts', array(
		'label'             => esc_html__( 'Show related posts', 'onetype' ),
		'section'           => 'onetype_post',
		'priority'          => 13,
		'type'              => 'checkbox',
		'active_callback' => function() {
			return is_single();
		}
	) );

	// Register Post comment manager setting
	$wp_customize->add_setting( 'onetype_post_comment', array(
		'default'           => 1,
		'sanitize_callback' => 'onetype_sanitize_checkbox',
	) );
	$wp_customize->add_control( 'onetype_post_comment', array(
		'label'             => esc_html__( 'Enable comment on post', 'onetype' ),
		'section'           => 'onetype_post',
		'priority'          => 15,
		'type'              => 'checkbox',
		'active_callback' => function() {
			return is_single();
		}
	) );

}
add_action( 'customize_register', 'onetype_post_customize_register' );

/**
 * Show control if post meta = enable
 */
function onetype_is_post_meta_enable() {

	if ( !is_single() ) {
		return false;
	}

	$option = get_theme_mod( 'onetype_post_meta', 'enable' );

	if ( $option == 'enable' ) {
		return true;
	} else {
		return false;
	}

}
