<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Product Widget
 */
class Widget_Onetype_Single_Product extends Widget_Base {

	/**
	 * Retrieve heading widget name.
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'onetype-single-product';
	}

	/**
	 * Retrieve heading widget title.
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Single Product', 'onetype' );
	}

	/**
	 * Retrieve heading widget icon.
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-woocommerce';
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'wc-single-product', 'flexslider' ];
	}

	/**
	 * Register heading widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @access protected
	 */
	protected function _register_controls() {

		$this->start_controls_section(
			'section_single_product_id',
			[
				'label' => esc_html__( 'Product ID', 'onetype' ),
			]
		);

		$this->add_control(
			'single_product_id',
			[
				'label'       => esc_html__( 'Product ID', 'onetype' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Enter product ID', 'onetype' )
			]
		);

		$this->add_control(
			'view',
			[
				'label' => esc_html__( 'View', 'onetype' ),
				'type' => Controls_Manager::HIDDEN,
				'default' => 'traditional',
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render heading widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();
		$id       = $settings['single_product_id'];

		if ( empty( $id ) ) {
			return;
		}

		$query_args = array(
			'posts_per_page' => 1,
			'post_status'    => 'publish',
			'post_type'      => 'product',
			'no_found_rows'  => 1,
			'p'              => absint( $id )
		);

		$query = new \WP_Query( $query_args );

		$this->onetype_single_product_content();
		?>

		<?php if ( $query ) : ?>

			<?php while ( $query->have_posts() ) : $query->the_post(); ?>

				<div class="single-product">

					<div class="product">

						<?php do_action( 'onetype_single_product_image' ); ?>

						<div class="summary entry-summary">
							<?php do_action( 'onetype_single_product_summary' ); ?>
						</div>

					</div>

				</div>

			<?php endwhile; ?>

		<?php endif; wp_reset_postdata();

	}

	/**
	 * Render heading widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @access protected
	 */
	protected function _content_template() {}

	public function onetype_single_product_content() {

		// Image
		add_action( 'onetype_single_product_image', 'woocommerce_show_product_sale_flash', 10 );
		add_action( 'onetype_single_product_image', 'woocommerce_show_product_images', 20 );

		// Summary
		add_action( 'onetype_single_product_summary', 'woocommerce_template_single_title', 5 );
		add_action( 'onetype_single_product_summary', 'woocommerce_template_single_rating', 10 );
		add_action( 'onetype_single_product_summary', 'woocommerce_template_single_price', 15 );
		add_action( 'onetype_single_product_summary', 'woocommerce_template_single_excerpt', 20 );
		add_action( 'onetype_single_product_summary', 'woocommerce_template_loop_add_to_cart', 25 );
		add_action( 'onetype_single_product_summary', 'woocommerce_template_single_meta', 30 );

	}

}

Plugin::instance()->widgets_manager->register_widget_type( new Widget_Onetype_Single_Product() );
