<?php
/**
 * Custom template tags used to integrate this theme with WooCommerce.
 *
 * @package    OneType
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2017, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

if ( ! function_exists( 'onetype_header_cart' ) ) :
/**
 * Display Header Cart
 *
 * @since  1.0.0
 */
function onetype_header_cart() {
	?>
		<div class="header-cart">
			<span>
				<?php onetype_cart_link(); ?>
			</span>
			<?php the_widget( 'WC_Widget_Cart', 'title=' ); ?>
		</div>
	<?php
}
endif;

if ( ! function_exists( 'onetype_cart_link' ) ) :
/**
 * Cart link
 *
 * @since  1.0.0
 */
function onetype_cart_link() { ?>
	<a class="cart-contents" href="<?php echo esc_url( WC()->cart->get_cart_url() ); ?>" title="<?php esc_attr_e( 'View your shopping cart', 'onetype' ); ?>">
		<span class="total"><?php echo wp_kses_data( WC()->cart->get_cart_subtotal() ); ?></span>
		<i class="fa fa-shopping-cart"></i>
		<span class="count"><?php echo wp_kses_data( WC()->cart->get_cart_contents_count() );?></span>
	</a>
	<?php
}
endif;

if ( ! function_exists( 'onetype_before_content' ) ) :
/**
 * Before Content
 * Wraps all WooCommerce content in wrappers which match the theme markup
 *
 * @since   1.0.0
 */
function onetype_before_content() {
	?>
	<div class="container">
		<div id="primary" class="content-area">
			<main id="main" class="site-main">
		<?php
}
endif;
add_action( 'woocommerce_before_main_content', 'onetype_before_content', 10 );

if ( ! function_exists( 'onetype_after_content' ) ) :
/**
 * After Content
 * Closes the wrapping divs
 *
 * @since   1.0.0
 */
function onetype_after_content() {
	?>
		</main><!-- #main -->
	</div><!-- #primary -->

	<?php
}
endif;
add_action( 'woocommerce_after_main_content', 'onetype_after_content', 10 );

if ( ! function_exists( 'onetype_after_sidebar' ) ) :
/**
 * After sidebar
 * Closes the container divs
 *
 * @since   1.0.0
 */
function onetype_after_sidebar() {
	?>
		</div><!-- .container -->
	<?php
}
endif;
add_action( 'woocommerce_sidebar', 'onetype_after_sidebar', 20 );

if ( ! function_exists( 'onetype_sorting_wrapper' ) ) :
/**
 * Sorting wrapper
 *
 * @since   1.0.0
 */
function onetype_sorting_wrapper() {
	echo '<div class="onetype-sorting">';
}
endif;
add_action( 'woocommerce_before_shop_loop', 'onetype_sorting_wrapper', 9 );

if ( ! function_exists( 'onetype_sorting_wrapper_close' ) ) :
/**
 * Sorting wrapper close
 *
 * @since   1.0.0
 */
function onetype_sorting_wrapper_close() {
	echo '</div>';
}
endif;
add_action( 'woocommerce_before_shop_loop', 'onetype_sorting_wrapper_close', 31 );

if ( ! function_exists( 'onetype_upsell_display' ) ) :
/**
 * Upsells
 * Replace the default upsell function with our own which displays the correct number product columns
 */
function onetype_upsell_display() {
	woocommerce_upsell_display( -1, 3 );
}
endif;
add_action( 'woocommerce_after_single_product_summary', 'onetype_upsell_display', 15 );

if ( ! function_exists( 'onetype_summary_seperator' ) ) :
/**
 * Seperator after product summary
 */
function onetype_summary_seperator() {
	echo '<div class="clear"></div>';
}
endif;
add_action( 'woocommerce_after_single_product_summary', 'onetype_summary_seperator', 5 );
